util

package
v0.5.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 18, 2025 License: MIT Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ConvertEmoji

func ConvertEmoji(shortcode string) string

ConvertEmoji converts a Slack emoji shortcode to Unicode emoji If the emoji is not found in the map, returns the original shortcode with colons

func ConvertEmojiInText

func ConvertEmojiInText(text string) string

ConvertEmojiInText converts all emoji shortcodes in a text string to Unicode emojis Example: "Hello :wave: :smile:" becomes "Hello 👋 😄"

Types

This section is empty.

Jump to